Estimates total sum abundance
total_sum_abundance.RdThis function estimates total sum abundance for numeric data in a matrix, for (1) all features and (2) all features with complete data.
Value
a data frame of estimates for (1) total sum abundance and (2) total sum abundance at complete features for each samples. The function also returns the number of features that are not NA at each sample and the number of features with complete data, across all sampmles, used to estimate total sum abundance at complete features.